export default {
    "index": 8,
    "lineNumber": 1,
    "column": 9,
    "message": "Unexpected keyword 'var'"
}